@@ -1,5 +1,5 @@
 inTimeZone <- function(tz, code) {
-  previous_tz <- Sys.getenv("TZ", Sys.timezone())
+  previous_tz <- currentTimeZone()
   tryCatch({
     Sys.setenv(TZ=tz)
     eval(code)
@@ -7,3 +7,7 @@ inTimeZone <- function(tz, code) {
     Sys.setenv(TZ=previous_tz)
   })
 }
+
+currentTimeZone <- function() {
+  Sys.getenv("TZ", Sys.timezone())
+}
